@@ -58,11 +58,22 @@ class CharacterOrMIAME(rpy2.robjects.methods.RS4):
     """ Abstract class """
     pass
 
-# class AssayData(rpy2.robjects.methods.RS4, rpy2.robjects.Environment):
-#     """ Abstract class. That class in a ClassUnionRepresentation
-#     in R, that a is way to create a parent class for existing classes.
-#     This is currently not modelled in Python. """
-#     pass
+class AssayData(rpy2.robjects.methods.RS4):
+    """ Abstract class. That class in a ClassUnionRepresentation
+     in R, that a is way to create a parent class for existing classes.
+     This is currently not modelled in Python. """
+    __rname__ = 'AssayData'
+    __metaclass__ = rpy2.robjects.methods.RS4_Type
+    
+    __accessors__ = (('featureNames', 'Biobase', 'featurenames', True,
+                      'maps Biobase::featureNames'),
+                     ('sampleNames', 'Biobase', 'samplenames', True,
+                      'maps Biobase::samplenames'),
+                     ('storageMode', 'Biobase', 'storagemode', True,
+                      'maps Biobase::storageMode')
+                     )
+
+
 
 class AnnotatedDataFrame(Versioned):
     ''' An annotated data.frame as defined in the R package Biobase'''
@@ -230,7 +241,7 @@ class ExpressionSet(ESet):
 
     def set_exprs(self, value):
         res = self._set_exprs(self, value)
-        return res
+        self.__sexp__ = res.__sexp__
 
     exprs = property(get_exprs, set_exprs,
                      None,
@@ -300,7 +311,7 @@ class MIAME(CharacterOrMIAME):
 
 _biobase_dict = {
     'AnnotatedDataFrame': AnnotatedDataFrame,
-    #'AssayData': AssayData,
+    'AssayData': AssayData,
     'chararacterORMIAME': CharacterOrMIAME,
     'eSet': ESet,
     'ExpressionSet': ExpressionSet,
