@@ -32,6 +32,8 @@ from rpy2.robjects.packages import importr
 base = importr('base')
 methods = importr('methods')
 getmethod = methods.getMethod
+selectmethod = methods.selectMethod
+
 __rname__ = 'Biostrings'
 
 biostrings = importr(__rname__)
@@ -138,9 +140,8 @@ class AAString(XString):
 
 class XStringSet(rpy2.robjects.methods.RS4):
     """ An abstract class, parent to *StringSet classes """
-    _subset = getmethod("[", 
-                        signature = "XStringSet",
-                        where = "package:Biostrings")
+    _subset = selectmethod("[", 
+                           signature = "XStringSet")
     _length = base.length
 
     r = None
