@@ -26,16 +26,14 @@ __rname__ = 'GGtools'
 import rpy2.robjects.methods
 import rpy2.robjects as robjects
 import rpy2.robjects.packages
+from rpy2.robjects.packages import importr
 
 conversion = robjects.conversion
 getmethod = robjects.baseenv.get("getMethod")
 
 import bioc.biostrings, bioc.iranges, bioc.ggbase
-rpy2.robjects.packages.quiet_require(__rname__)
+__rpackage__ = importr(__rname__)
 
-package_env = robjects.baseenv['as.environment']('package:%s' %__rname__)
-__rpackage__ = robjects.packages.SignatureTranslatedPackage(package_env, 
-                                                            __rname__)
 
 StrVector = robjects.StrVector
 
@@ -43,13 +41,22 @@ StrVector = robjects.StrVector
 # class HbTestResults(rpy2.robjects.methods.RS4):
 #     __rname__ = 'hbTestResults'
 #     __metaclass__ = rpy2.robjects.methods.RS4_Type
-
 #     __accessors__ = (('pvals', 'GGtools', 'pvals', True, None),
 #                      ('locs', 'GGtools', None, True, None),
 #                      ('hscores', 'GGtools', None, False, None))
 
+class MultffManager(rpy2.robjects.methods.RS4):
+    __rname__ = 'multffManager'
+    __metaclass__ = rpy2.robjects.methods.RS4_Type
+
+class MaxChisq(rpy2.robjects.methods.RS4):
+    __rname__ = 'maxchisq'
+    __metaclass__ = rpy2.robjects.methods.RS4_Type
+
 _ggtools_dict = {
-#    'hbTestResults': HbTestResults
+#    'hbTestResults': HbTestResults,
+    'multffManager': MultffManager,
+    'maxchisq': MaxChisq
     }
 
 original_conversion = robjects.conversion.ri2py
@@ -67,3 +74,4 @@ def ggtools_conversion(robj):
     return pyobj
 
 robjects.conversion.ri2py = ggtools_conversion
+ 
